# pychoco

Minimal choco command for use on non-Windows platforms.

## Installation

```shell
pip install chocolatey-choco
```

## Command line usage

```plain
Usage: choco [OPTIONS] COMMAND [ARGS]...

  Root command.

Options:
  --help  Show this message and exit.

Commands:
  apikey
  config
  new
  pack
  push
```
